#!/bin/sh

###########################################################################
#
# /cluster/src/pov/4_clusterfilm_mpeg.sh
# 11.01.2005 Fred Koegler
# Zum 29.01.2005 fr die BraLUG - "Brandenburg Clusternight"
#
# MPEG2 / MPEG4 Filme mit ffmpeg aus POV-Ray - PNG-Dateien zusammenstellen
#
# Bemerkungen:
# - Umweg ber YUV420P - rawvideo , um Filmszenen mit cp zusammenzufgen
# - PNG -> YUV -> MPEG hatte mit verschiedenen Einstellungen nicht Erfolg
# 
# 1. Filmszenen erstellen:
# - zus. Start-/Endframe einfgen, die bei MP4-YUV-Konvertierung verlorengehen
# - PNG -> MP4 (Qualitt=1) -> YUV
#
# 2. Filmszenen zusammenfgen:
# - cp 1.YUV 2.YUV ... > Film.YUV
#
# 3. Filme erzeugen:
# - Film.YUV -> Film_6000.VOB (6000 kbits/s MPEG2)
# - Film.YUV -> Film_6000.MP4 (6000 kbits/s MPEG4)
# - Film.YUV -> Film_.MP4     (Qualitt=1 MPEG4)
#
###########################################################################

# png_mp4_yuv format name.png name.mp4 name.yuv
png_mp4_yuv ()
{
  moviepath="/cluster/tmp/pov/"
  ffmpeg -y -loop -i "$moviepath$3.png" \
    -title "Clusternight Film" -author "Fred Koegler" \
    -copyright "Fred Koegler  2004" -comment "Private Film!" \
    -s $2 -r 25 -aspect 4:3 -hq -me full -an \
    -vcodec mpeg4 -t $4 -qscale 1 "$moviepath$1.mp4"
  ffmpeg -y -i "$moviepath$1.mp4" "$moviepath$1.yuv" 
}

# png_mp4_yuv format name.png name.mp4 name.yuv
yuv_mp4_vob ()
{
  moviepath="/cluster/tmp/pov/"
  ffmpeg -y -s $2 -i "$moviepath$1.yuv" \
    -title "Clusternight Film" -author "Fred Koegler" \
    -copyright "Fred Koegler  2004" -comment "Private Film!" \
    -s $2 -r 25 -aspect 4:3 -hq -me full -an \
    -vcodec mpeg2video -b 6000 "$moviepath$1_6000.vob" \
    -vcodec mpeg4 -b 6000 "$moviepath$1_6000.mp4" \
    -vcodec mpeg4 -qscale 1 "$moviepath$1_.mp4"
}

# 12s Achterbahntestfahrt Einzelfilm schneiden, kleben und erzeugen
#cp /cluster/tmp/pov/clusta_01_001.png /cluster/tmp/pov/clusta_01_000.png
#cp /cluster/tmp/pov/clusta_01_300.png /cluster/tmp/pov/clusta_01_301.png
png_mp4_yuv "clusta_640x480" "640X480" "clusta_01_%3d" "00:00:12.080"
yuv_mp4_vob "clusta_640x480" "640X480"

# 00:  0.. 2 2s Titel ohne Licht
#cp /cluster/tmp/pov/clustv_01_01.png /cluster/tmp/pov/clustv_00_0.png
#cp /cluster/tmp/pov/clustv_01_01.png /cluster/tmp/pov/clustv_00_1.png
png_mp4_yuv "clustv_00" "720X540" "clustv_00_%1d" "00:00:02.08"
# 01:  2.. 5 3s Titel ... Licht an 
#cp /cluster/tmp/pov/clustv_01_01.png /cluster/tmp/pov/clustv_01_00.png
#cp /cluster/tmp/pov/clustv_01_75.png /cluster/tmp/pov/clustv_01_76.png
png_mp4_yuv "clustv_01" "720X540" "clustv_01_%2d" "00:00:03.08"
# 02:  5.. 8 3s Titel anzeigen
#cp /cluster/tmp/pov/clustv_01_75.png /cluster/tmp/pov/clustv_02_0.png
#cp /cluster/tmp/pov/clustv_01_75.png /cluster/tmp/pov/clustv_02_1.png
png_mp4_yuv "clustv_02" "720X540" "clustv_02_%1d" "00:00:03.08"
# 03:  8..11 3s fredhase einschwenken   
#cp /cluster/tmp/pov/clustv_03_01.png /cluster/tmp/pov/clustv_03_00.png
#cp /cluster/tmp/pov/clustv_03_75.png /cluster/tmp/pov/clustv_03_76.png
png_mp4_yuv "clustv_03" "720X540" "clustv_03_%2d" "00:00:03.08"
# 04: 11..14 3s fredhase anzeigen    
#cp /cluster/tmp/pov/clustv_04_0.png /cluster/tmp/pov/clustv_04_00.png
#cp /cluster/tmp/pov/clustv_04_0.png /cluster/tmp/pov/clustv_04_01.png
png_mp4_yuv "clustv_04_0" "720X540" "clustv_04_0%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_11.png /cluster/tmp/pov/clustv_04_10.png
png_mp4_yuv "clustv_04_1" "720X540" "clustv_04_1%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_22.png /cluster/tmp/pov/clustv_04_20.png
#cp /cluster/tmp/pov/clustv_04_22.png /cluster/tmp/pov/clustv_04_21.png
#rm /cluster/tmp/pov/clustv_04_22.png
png_mp4_yuv "clustv_04_2" "720X540" "clustv_04_2%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_33.png /cluster/tmp/pov/clustv_04_30.png
#cp /cluster/tmp/pov/clustv_04_33.png /cluster/tmp/pov/clustv_04_31.png
png_mp4_yuv "clustv_04_3" "720X540" "clustv_04_3%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_44.png /cluster/tmp/pov/clustv_04_40.png
#cp /cluster/tmp/pov/clustv_04_44.png /cluster/tmp/pov/clustv_04_41.png
png_mp4_yuv "clustv_04_4" "720X540" "clustv_04_4%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_55.png /cluster/tmp/pov/clustv_04_50.png
#cp /cluster/tmp/pov/clustv_04_55.png /cluster/tmp/pov/clustv_04_51.png
png_mp4_yuv "clustv_04_5" "720X540" "clustv_04_5%1d" "00:00:00.48"
#cp /cluster/tmp/pov/clustv_04_66.png /cluster/tmp/pov/clustv_04_60.png
#cp /cluster/tmp/pov/clustv_04_66.png /cluster/tmp/pov/clustv_04_61.png
png_mp4_yuv "clustv_04_6" "720X540" "clustv_04_6%1d" "00:00:00.48"
cat /cluster/tmp/pov/clustv_04_0.yuv /cluster/tmp/pov/clustv_04_1.yuv \
    /cluster/tmp/pov/clustv_04_2.yuv /cluster/tmp/pov/clustv_04_3.yuv \
    /cluster/tmp/pov/clustv_04_4.yuv /cluster/tmp/pov/clustv_04_5.yuv \
    /cluster/tmp/pov/clustv_04_6.yuv > /cluster/tmp/pov/clustv_04.yuv
# 05: 14..17 3s fredhase ausschwenken   
#cp /cluster/tmp/pov/clustv_05_01.png /cluster/tmp/pov/clustv_05_00.png
#cp /cluster/tmp/pov/clustv_05_75.png /cluster/tmp/pov/clustv_05_76.png
png_mp4_yuv "clustv_05" "720X540" "clustv_05_%2d" "00:00:03.08"
# 06: 17..20 3s Titel anzeigen
# 07: 20..23 3s animation einschwenken    
#cp /cluster/tmp/pov/clustv_07_01.png /cluster/tmp/pov/clustv_07_00.png
#cp /cluster/tmp/pov/clustv_07_75.png /cluster/tmp/pov/clustv_07_76.png
png_mp4_yuv "clustv_07" "720X540" "clustv_07_%2d" "00:00:03.08"
# 08: 23..29 6s animation anzeigen    
#cp /cluster/tmp/pov/clustv_08_001.png /cluster/tmp/pov/clustv_08_000.png
#cp /cluster/tmp/pov/clustv_08_150.png /cluster/tmp/pov/clustv_08_151.png
png_mp4_yuv "clustv_08" "720X540" "clustv_08_%3d" "00:00:06.08"
# 09: 29..32 3s animation ausschwenken    
#cp /cluster/tmp/pov/clustv_09_01.png /cluster/tmp/pov/clustv_09_00.png
#cp /cluster/tmp/pov/clustv_09_75.png /cluster/tmp/pov/clustv_09_76.png
png_mp4_yuv "clustv_09" "720X540" "clustv_09_%2d" "00:00:03.08"
# 10: 32..35 3s Titel anzeigen
# 11: 35..38 3s poster einschwenken    
#cp /cluster/tmp/pov/clustv_11_01.png /cluster/tmp/pov/clustv_11_00.png
#cp /cluster/tmp/pov/clustv_11_75.png /cluster/tmp/pov/clustv_11_76.png
png_mp4_yuv "clustv_11" "720X540" "clustv_11_%2d" "00:00:03.08"
# 12: 38..41 3s poster anzeigen    
#cp /cluster/tmp/pov/clustv_11_75.png /cluster/tmp/pov/clustv_12_0.png
#cp /cluster/tmp/pov/clustv_11_75.png /cluster/tmp/pov/clustv_12_1.png
png_mp4_yuv "clustv_12" "720X540" "clustv_12_%1d" "00:00:03.08"
# 13: 41..44 3s poster ausschwenken    
#cp /cluster/tmp/pov/clustv_13_01.png /cluster/tmp/pov/clustv_13_00.png
#cp /cluster/tmp/pov/clustv_13_75.png /cluster/tmp/pov/clustv_13_76.png
png_mp4_yuv "clustv_13" "720X540" "clustv_13_%2d" "00:00:03.08"
# 14: 44..47 3s Titel anzeigen
# 15: 47..49 2s Titel ohne Licht anzeigen
# 53: 50..53 3s bralug einschwenken   
#cp /cluster/tmp/pov/clustv_53_01.png /cluster/tmp/pov/clustv_53_00.png
#cp /cluster/tmp/pov/clustv_53_75.png /cluster/tmp/pov/clustv_53_76.png
png_mp4_yuv "clustv_53" "720X540" "clustv_53_%2d" "00:00:03.08"
# 54: 53..56 3s bralug anzeigen    
#cp /cluster/tmp/pov/clustv_54_01.png /cluster/tmp/pov/clustv_54_00.png
png_mp4_yuv "clustv_54" "720X540" "clustv_54_%2d" "00:00:03.08"
# 55: 56..59 3s bralug ausschwenken   
#cp /cluster/tmp/pov/clustv_55_01.png /cluster/tmp/pov/clustv_55_00.png
#cp /cluster/tmp/pov/clustv_55_75.png /cluster/tmp/pov/clustv_55_76.png
png_mp4_yuv "clustv_55" "720X540" "clustv_55_%2d" "00:00:03.08"

# 60.8s Vorspannfilm schneiden, kleben und erzeugen
cat /cluster/tmp/pov/clustv_00.yuv /cluster/tmp/pov/clustv_01.yuv \
    /cluster/tmp/pov/clustv_02.yuv /cluster/tmp/pov/clustv_53.yuv \
    /cluster/tmp/pov/clustv_54.yuv /cluster/tmp/pov/clustv_55.yuv \
    /cluster/tmp/pov/clustv_02.yuv /cluster/tmp/pov/clustv_07.yuv \
    /cluster/tmp/pov/clustv_08.yuv /cluster/tmp/pov/clustv_09.yuv \
    /cluster/tmp/pov/clustv_02.yuv /cluster/tmp/pov/clustv_11.yuv \
    /cluster/tmp/pov/clustv_12.yuv /cluster/tmp/pov/clustv_13.yuv \
    /cluster/tmp/pov/clustv_02.yuv /cluster/tmp/pov/clustv_03.yuv \
    /cluster/tmp/pov/clustv_04.yuv /cluster/tmp/pov/clustv_05.yuv \
    /cluster/tmp/pov/clustv_02.yuv /cluster/tmp/pov/clustv_00.yuv \
    > /cluster/tmp/pov/clustv_720x540.yuv
yuv_mp4_vob "clustv_720x540" "720X540"

# 60s Achterbahnfilm schneiden, kleben und erzeugen
#cp /cluster/tmp/pov/clustf_0_0001.png /cluster/tmp/pov/clustf_0_0000.png
#cp /cluster/tmp/pov/clustf_0_1500.png /cluster/tmp/pov/clustf_0_1501.png
png_mp4_yuv "clustf_0_720x540" "720X540" "clustf_0_%4d" "00:01:00.080"
yuv_mp4_vob "clustf_0_720x540" "720X540"

# 40s Sturzflugfilm schneiden, kleben und erzeugen
#cp /cluster/tmp/pov/clustf_1_0001.png /cluster/tmp/pov/clustf_1_0000.png
#cp /cluster/tmp/pov/clustf_1_1000.png /cluster/tmp/pov/clustf_1_1001.png
png_mp4_yuv "clustf_1_720x540" "720X540" "clustf_1_%4d" "00:00:40.080"
yuv_mp4_vob "clustf_1_720x540" "720X540"

# 161.8s Gesamtfilm schneiden, kleben und erzeugen
cat /cluster/tmp/pov/clustv_720x540.yuv \
    /cluster/tmp/pov/clustf_0_720x540.yuv \
    /cluster/tmp/pov/clustf_1_720x540.yuv \
    > /cluster/tmp/pov/clusterfilm_720x540.yuv
yuv_mp4_vob "clusterfilm_720x540" "720X540"

# Ende
unset png_mp4_yuv
unset yuv_mp4_vob
