// ###########################################################################
// #
// # /cluster/src/pov/clusta_01_.pov
// # 07.11.2004 Fred Koegler
// # Zum 29.01.2005 fuer die BraLUG - "Brandenburg Clusternight"
// #
// # Achterbahntestfahrt mit 2x Tux in einem Bob bei Tageslicht
// # Verwendung im Vorspann/Trailer als Film-im-Film - Bilder
// #
// # HOWTO:
// # - /cluster/src/pov/0_clusta_01_pov.sh
// #
// # speziell verwendete POVRay Elemente:
// # - cubic_spline & prism & lathe : Tux-Schnabel, Tux-Fuesze
// # - bicubic_patch                : Bob-Koerper (, Tux-Fluegel, Tux-Rucksack)
// # - blob                         : schwarzer Tux-Koerper
// # - macro & Vektorfunktionen     : Achterbahnform, Bewegung
// # - fopen & write & fclose       : Textdateiausgabe fuer Tondaten
// # 
// ###########################################################################
#version 3.1;

#declare show_bahn = 1;
#declare show_bob  = 1;
#declare show_tux  = 1;
//#declare testausgabe  = 1;
//#declare wavtxtausgabe  = 1;

// ############################################################################################################
#declare bob_steps = 8;
;#declare bob_steps = 6;

#declare balls_per_seg = 20;
#declare diffs_per_ball = 2;
#declare seg_len = 5;
#declare t_time = 12.; // Vorgabedauer 12 s = 300 Bilder / 25 Bilder/s 
#declare t_fact = t_time/12.008; // Vorgabedauer ... zu Istdauer 12.008 s
#declare t_clock = clock/t_fact; // Bahnzeit 0..Istende
#declare b_clock = clock/t_time; // normierte Bobzeit 0..1
#declare paint_1 = 1;
#declare paint_2 = 1;
#declare paint_3 = 1;
#declare tux_unit = 5. / 1.195; // massstab-tux: 5 units / 1 m  
#declare a00 = tux_unit * 9.81; // units/s/s
#declare v00 = tux_unit * 10. / 3.6; // Startgeschwindigkeit 10 km/h in units/s
#declare t1 = 0.0;
#declare s1 = 0.0;
#declare v1 = v00;
#declare v_min = v1;
#declare v_max = v1;
#declare a_max = 0.0;
// ############################################################################################################

#ifdef (wavtxtausgabe)
  #fopen wavtxt "wav.txt" write
  #declare zeile = concat("wav_time ",str(t_time,10,5));
  #write (wavtxt,zeile,"\n")
#end

global_settings
{
  adc_bailout 0.0039
  ambient_light color rgb .5*<.1,.1,.1>
  assumed_gamma 1.0
  irid_wavelength <0.25, 0.18, 0.14>
  max_trace_level 10
}
#ifdef (show_bob)
  #include "/cluster/src/pov/bob.pov"
  init_bob(bob_steps) 
#end
#ifdef (show_tux)
  #include "/cluster/src/pov/tux.pov" 
#end

// ############################################################################################################
#macro bob_tuxies(rot,tran)
  #ifdef (show_bob)
    object { bob translate <0,2.8,0> rotate rot translate tran }
  #end
  // ############################################################################################################
  #ifdef (show_tux)
    #declare xyz_tux_eye_rechts_rotate = <-2,+3,10>;
    #declare xyz_tux_eye_links_rotate  = <-2,+3,10>;
    #declare xyz_tux_eye_rechts_lied_rotate = < 30, -15 , 0 >; 
    #declare xyz_tux_eye_links_lied_rotate  = < 30, -15 , 0 >; 
    #declare xyz_tux_head_rotate = <-15+15*cos(b_clock*4*pi),20+35*cos(b_clock*4*pi),0>;
    #declare xyz_tux_foot_rechts_rotate = <65,0,0>;
    #declare xyz_tux_foot_rechts_trans = <0,20,-70>;
    #declare xyz_tux_foot_links_rotate = <65,0,0>;
    #declare xyz_tux_foot_links_trans = <0,20,-70>;
    #declare xyz_tux_body_trans  = <0,0,-10>;
    #declare xyz_tux_rotate = <0,-90,0>;
    #declare xyz_tux_trans = <+20,-100,0>;

    #declare xyz_tux_body_light = 0.25;
    init_tux(30)
    object { tux scale .02 translate <0,2.9,0> rotate rot translate tran }

    #declare xyz_tux_eye_rechts_rotate = <+5,-8,10>;
    #declare xyz_tux_eye_links_rotate  = <+5,-8,10>;
    #declare xyz_tux_eye_rechts_lied_rotate = < 40, +15 , 0 >; 
    #declare xyz_tux_eye_links_lied_rotate  = < 40, +15 , 0 >; 
    #declare xyz_tux_head_rotate = <+15-10*cos(b_clock*6*pi),40-40*sin(b_clock*6*pi),0>;
    #declare xyz_tux_foot_rechts_rotate = <65,0,0>;
    #declare xyz_tux_foot_rechts_trans = <0,20,-70>;
    #declare xyz_tux_foot_links_rotate = <65,0,0>;
    #declare xyz_tux_foot_links_trans = <0,20,-70>;
    #declare xyz_tux_body_trans  = <0,0,-15>;
    #declare xyz_tux_rotate = <0,-90,0>;
    #declare xyz_tux_trans = <-120,-90,0>;

    #declare xyz_tux_body_light = 0.25;
    init_tux(30)
    object { tux scale .02 translate <0,2.9,0> rotate rot translate tran }
  #end
  // ############################################################################################################
#end

// ############################################################################################################
#ifdef (show_bahn) 
  #declare ro = 0.25;
  #declare zd = 1.25;
  #declare ru = 0.50;
  #declare yd =-1.50;
  #declare rs = 0.20;
  #declare rd = sqrt(yd*yd+zd*zd);
  #declare rdro = rd+2.2*ro;
  #declare ydro = yd-yd*sqrt(rdro/rd);
  #declare zdro = zd*sqrt(rdro/rd);
  #declare segment_0 =
    union
    {
      cylinder { <0,0,+zd>, <0,yd,0>, rs }
      cylinder { <0,0,-zd>, <0,yd,0>, rs }
      texture  { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #declare segment_1 =
    union
    {
      sphere { <0,0,-zd>, ro }
      sphere { <0,0,+zd>, ro }
      sphere { <0,yd,0>, ru }
      scale <10,1,1>
      texture { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #declare bob_rolls =
    union
    {
      difference { sphere { <0,+ydro,-zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,-zd>, <+5*ro,0,-zd>, 1.20*ro } }
      difference { sphere { <0,+ydro,+zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,+zd>, <+5*ro,0,+zd>, 1.20*ro } }
      sphere { <0,+ydro+ro,0>, 2*ro scale <1.0,1,1> }
      cylinder { <0,+ydro+ro,+zdro>, <0,+ydro+ro,-zdro>, 0.8*ro } 
      cylinder { <0,+ydro+ro,-zdro>, <+1.0*ro,+ydro+4.5*ro,-zdro+0.5*ro>, 0.4*ro } 
      cylinder { <0,+ydro+ro,+zdro>, <+1.0*ro,+ydro+4.5*ro,+zdro-0.5*ro>, 0.4*ro } 
      texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
    }
  #macro bob_beam (rot0,tran0,rot1,tran1)
    cylinder 
    {
      tran0+vrotate(<0,+ydro+ro,0>,rot0), tran1+vrotate(<0,+ydro+ro,0>,rot1), ro
      texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
    }
  #end
  #declare akt_seg = 0;
  #declare akt_tran = <0,0,0>;
  #declare akt_rot = <0,0,0>;
  #declare bob_front_s = 99999.99;
  #declare bob_pos_s = 99999.99;
  #declare all_i = balls_per_seg * diffs_per_ball;

  #macro segment(start_rot,diff_rot0,start_tran,diff_s0)
    #declare akt_seg = akt_seg + 1;
    #local diff_s = diff_s0 / all_i;
    #declare diff_rot = diff_rot0 / all_i;
    #declare now_tran = start_tran;
    #declare now_rot = start_rot;
    #ifndef(invisible)
      object { segment_0 rotate now_rot translate now_tran }
    #end
    #declare now_i = 0;
    #while (now_i < all_i)
      #declare now_i = now_i + 1;
      #declare s1 = s1 + diff_s;
      #declare a1 = - vrotate(<1,0,0>,now_rot).y * a00;
// ############################################################################################################
      #declare v0 = v1;
      #declare v1 = sqrt(v0*v0+2.0*diff_s*a1);
      #declare t0 = t1;
      #declare t1 = t0+2.0*diff_s/max(v0+v1,1E-10);
#ifdef (wavtxtausgabe)
  #declare zeile = concat("start ",str(t0*t_fact,10,5)," end ",str(t1*t_fact,10,5));
  #declare zeile = concat(zeile," freq ",str(100.0+(v0+v1)/1.0,10,5));
  #declare laut = max(abs(diff_rot0.z),max(abs(diff_rot0.x),abs(diff_rot0.y))) / (4.0*20.0);
  #declare laut = laut + (v0+v1) / (1.5*tux_unit*100.0/3.6);
  #declare laut = laut * 0.7;
  #declare zeile = concat(zeile," min 0 max ",str(laut,10,5)," typ 0");
  #write (wavtxt,zeile,"\n")
#end
      #ifdef (testausgabe)
        #declare a_max = max(a1,a_max);
        #declare v_max = max(v1,v_max);
        #declare v_min = min(v1,v_min);
      #end
      #if (paint_3)
        #if (paint_1 & (t1>=t_clock))
          #declare paint_1 = 0;
//#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," <",str(now_rot.x,8,3),",",str(now_rot.y,8,3),",",str(now_rot.z,8,3),">\n")
//#debug concat("### s1 ",str(s1,8,0),", v1 ",str(v1,8,3),", a1 ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")
          object { bob_rolls rotate now_rot translate now_tran }
          #declare bob_back_tran = now_tran;    
          #declare bob_back_rot = now_rot;    
          #declare bob_pos_s = s1 + 2.5;
          #declare bob_front_s = s1 + 5.5;
        #end
        #if (paint_2 & (bob_pos_s <= s1))
          #declare paint_2 = 0;
//#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," <",str(now_rot.x,8,3),",",str(now_rot.y,8,3),",",str(now_rot.z,8,3),">\n")
          #declare now_rot_real = now_rot+diff_rot*(bob_pos_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(<bob_pos_s-s1,0,0>,now_rot);
          bob_tuxies(now_rot_real,now_tran_real)
//          #declare xyz_camera         = now_tran_real+vrotate(<2,3.75,0>,now_rot_real);
//          #declare xyz_camera_look_at = now_tran_real+vrotate(<10,3,0>,now_rot_real);
//          #declare xyz_camera_sky     = vrotate(<0,1,0>,now_rot_real);
          #declare xyz_camera         = now_tran_real+vrotate(<.5,4,-18>,now_rot_real+<0,0+60*0.5*(1-cos(b_clock*4*pi)),0>);
          #declare xyz_camera_look_at = now_tran_real+vrotate(<.5,2,0>,now_rot_real);
          #declare xyz_camera_sky     = <0,1,0>;
        #end
        #if (paint_3 & (bob_front_s <= s1))
          #declare paint_3 = 0;
//#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," <",str(now_rot.x,8,3),",",str(now_rot.y,8,3),",",str(now_rot.z,8,3),">\n")
          #declare now_rot_real = now_rot + diff_rot*(bob_front_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(<bob_front_s-s1,0,0>,now_rot);
          object { bob_rolls scale <-1,1,1> rotate now_rot_real translate now_tran_real }
          bob_beam(now_rot_real,now_tran_real,bob_back_rot,bob_back_tran)
        #end
      #end
      #ifndef(invisible)
        #if (mod(now_i,diffs_per_ball) = 0)
          object { segment_1 rotate now_rot translate now_tran }
        #end
      #end
      #declare now_tran = now_tran + vrotate(<diff_s,0,0>,now_rot);
      #declare now_rot = now_rot + diff_rot;
    #end
    #declare akt_tran = now_tran;
    #declare akt_rot = now_rot;
  #end

// ############################################################################################################
  segment(<0,0,0>,<0,0,-5>,<20,-2.75,0>,seg_len)
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,-5>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,5>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,10>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,10>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,5>,akt_tran,seg_len) 

  segment(akt_rot,<2,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<4,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<6,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<8,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<10,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  

  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-10,-10,0>,akt_tran,seg_len)  

  segment(akt_rot,<-8,-10,0>,akt_tran,seg_len) 
  segment(akt_rot,<-6,-10,0>,akt_tran,seg_len)
  segment(akt_rot,<-4,-7,0>,akt_tran,seg_len)
  segment(akt_rot,<-2,-3,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<-2,3,0>,akt_tran,seg_len) 
  segment(akt_rot,<-4,7,0>,akt_tran,seg_len) 
  segment(akt_rot,<-6,10,0>,akt_tran,seg_len) 
  segment(akt_rot,<-8,10,0>,akt_tran,seg_len) 

  segment(akt_rot,<8,10,0>,akt_tran,seg_len) 
  segment(akt_rot,<6,10,0>,akt_tran,seg_len)
  segment(akt_rot,<4,7,0>,akt_tran,seg_len)
  segment(akt_rot,<2,3,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<2,-3,0>,akt_tran,seg_len) 
  segment(akt_rot,<4,-7,0>,akt_tran,seg_len) 
  segment(akt_rot,<6,-10,0>,akt_tran,seg_len) 
  segment(akt_rot,<8,-10,0>,akt_tran,seg_len) 

  segment(akt_rot,<10,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  

  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<0,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-10,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-8,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-6,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-4,-10,0>,akt_tran,seg_len)  
  segment(akt_rot,<-2,-10,0>,akt_tran,seg_len)  

  segment(akt_rot,<0,0,5>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,5>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,0>,akt_tran,seg_len*1.0205) 
  segment(akt_rot,<0,0,-5>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len) 
  segment(akt_rot,<0,0,-5>,akt_tran,seg_len*0.7712) 

  #ifdef (testausgabe)
#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," <",str(now_tran.x,8,3),",",str(now_tran.y,8,3),",",str(now_tran.z,8,3),">\n")
#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," <",str(now_rot.x,8,3),",",str(now_rot.y,8,3),",",str(now_rot.z,8,3),">\n")
#debug concat("### s1 ",str(s1,8,3),", v1   ",str(v1,8,3),", a1   ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")
#debug concat("### s  ",str(s1,8,3),", vmax ",str(v_max,8,3),", amax ",str(a_max,8,3),", t  ",str(t1,8,3),", vmin ",str(v_min,8,3),"\n")
  #end

#declare invisible = 1;

  segment(akt_rot,<0,0,-5>,akt_tran,seg_len)
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,-10>,akt_tran,seg_len)
  segment(akt_rot,<0,0,-5>,akt_tran,seg_len)

#ifdef (wavtxtausgabe)
  #declare zeile = concat("start 0 end ",str(t_time,10,5)," freq .3 min .50 max 0.80 typ 0");
  #write (wavtxt,zeile,"\n")
  #declare zeile = concat("start 0 end ",str(t_time,10,5)," freq -1 min 0 max 4E-11 typ 1");
  #write (wavtxt,zeile,"\n")
  #write (wavtxt,"ende\n")
  #fclose wavtxt
#end

#end

// ############################################################################################################
#declare xyz_camera_zoom = 2;
camera {
  location xyz_camera
  sky xyz_camera_sky
  look_at xyz_camera_look_at
  direction xyz_camera_zoom*vnormalize(xyz_camera_look_at-xyz_camera)
}

// ############################################################################################################
#declare sonne = light_source { <0,0,0> colour rgb .9 }
union 
{
  object { sonne }
  object { sonne }
  object { sonne }
  translate <-50000,100000,-100000>
}

// ############################################################################################################
#declare SkyBlue = color red 0.196078 green 0.6 blue 0.8;
#declare MidnightBlue = color red 0.184314 green 0.184314 blue 0.309804;
sky_sphere 
{
  pigment 
  {
    gradient y
    color_map 
    {
      [ 0.1  color SkyBlue ]
      [ 0.4  color SkyBlue ]
      [ 0.8  color MidnightBlue ]
      [ 1.0  color MidnightBlue ]
    }
    scale 2
    translate -1
  }
}
