// ###########################################################################
// #
// # /cluster/src/pov/clustf_0_.pov
// # 23.12.2004 Fred Koegler
// # Zum 29.01.2005 fuer die BraLUG - "Brandenburg Clusternight"
// #
// # Achterbahnfahrt mit 2x Tux in einem Bob bei Nacht bis zum Absturz
// # Verwendung als Teilfilm #2 : Hauptfilm = Achterbahnfahrt in der Nacht
// #
// # HOWTO:
// # - /cluster/src/pov/2_clustf_0_pov.sh
// #
// # speziell verwendete POVRay Elemente:
// # - rand & superellipsoid        : Sternenhimmel
// # - cubic_spline & prism & lathe : Tux-Schnabel, Tux-Fuesze
// # - bicubic_patch                : Tux-Fluegel, Tux-Rucksack, Bob-Koerper
// # - blob                         : schwarzer Tux-Koerper
// # - macro & Vektorfunktionen     : Achterbahnform, Bewegung
// # 
// ###########################################################################
#version 3.1;

#macro soft(cl)
  .5*(1-cos(cl*pi))
#end
#declare _licht = 1;
#declare t_clock = max(0,-1+clock*60);
#if (t_clock >= 55)
 #declare xyz_camera_55_59 = soft((t_clock-55)*1/3);
 #if (t_clock >= 58)
  #declare xyz_camera_55_59 = 1;
// Licht aus
  #if (t_clock >= 58.5)
   #declare _licht = max(0,min(1,(1-clock)*2*60));
  #end
 #end
#else 
 #declare xyz_camera_ahead = 1;
#end
#if ((t_clock >= 0) & (t_clock < 5))
// Licht an und von Rechts-Tuxansicht auf Bahn schwenken
 #declare _licht = min(1,clock*60);
 #declare xyz_camera_00_05 = soft((t_clock-0)*1/5);
#else
 #if ((t_clock >= 7) & (t_clock < 16))
// im Looping von Bahn auf Rechts-Tuxansicht und nach Looping wieder in die Bahn schwenken
  #declare xyz_camera_07_16 = soft((t_clock-7)*1/2);
  #if (t_clock >= 9)
   #declare xyz_camera_07_16 = 1;
  #end
  #if (t_clock >= 13)
   #declare xyz_camera_07_16 = 1-soft((t_clock-13)*1/3);
  #end
 #else
  #if ((t_clock >= 20) & (t_clock < 27))
// im Abwrtskreisel von Bahn auf Links-Tuxansicht und wieder in die Bahn schwenken
   #declare xyz_camera_20_27 = soft((t_clock-20)*1/2);
   #if (t_clock >= 22)
    #declare xyz_camera_20_27 = 1;
   #end
   #if (t_clock >= 24)
    #declare xyz_camera_20_27 = 1-soft((t_clock-24)*1/3);
   #end
  #else
   #if ((t_clock >= 33.5) & (t_clock < 45))
// im Aufwrtskreisel von Bahn auf Rechts-Tuxansicht und wieder in die Bahn schwenken
    #declare xyz_camera_33_40 = soft((t_clock-33.5)*1/3);
    #if (t_clock >= 36.5)
     #declare xyz_camera_33_40 = 1;
    #end
    #if (t_clock >= 42)
     #declare xyz_camera_33_40 = 1-soft((t_clock-42)*1/3);
    #end
   #end
  #end
 #end
#end

#declare star_start = 246;
#declare show_stars = 1;

#declare show_bahn = 1;
#declare show_bob  = 1;
#declare show_tux  = 1;

// ############################################################################################################
#declare dist = 200;
#declare star_distance = 4*dist;
#declare xyz_camera         = <-70,20,-50>;
#declare xyz_camera_look_at = <-20,-50,0>;
#declare xyz_camera_sky     = <0,1,0>;
#declare xyz_camera_zoom = 1;

#declare bob_steps = 6;

#declare seg_len = 5;
#declare paint_1 = 1;
#declare paint_2 = 1;
#declare paint_3 = 1;
#declare tux_unit = 5. / 1.195; // massstab-tux: 5 units / 1 m  
#declare a00 = tux_unit * 9.81; // units/s/s
#declare v00 = tux_unit * 5. / 3.6; // Startgeschwindigkeit 10 km/h in units/s
#declare t1 = 0.0;
#declare s1 = 0.0;
#declare v1 = v00;
// ############################################################################################################

global_settings
{
  adc_bailout 0.0039
  ambient_light color rgb _licht*.5*<.1,.1,.1>
  assumed_gamma 1.0
  irid_wavelength <0.25, 0.18, 0.14>
  max_trace_level 10
}

// ############################################################################################################
#ifdef (show_bob)
  #ifdef (show_bob)
    #include "/cluster/src/pov/bob.pov"
    init_bob(bob_steps) 
  #end
  #ifdef (show_tux)
    #include "/cluster/src/pov/tux.pov" 
  #end
  #macro bob_tuxies(rot0,rot1,tran)
    #ifdef (show_bob)
      object { bob translate <0,2.8,0> rotate rot0 rotate rot1 translate tran }
    #end
    #ifdef (show_tux)
      #declare xyz_tux_eye_rechts_rotate = <-2,+3,10>;
      #declare xyz_tux_eye_links_rotate  = <-2,+3,10>;
      #declare xyz_tux_eye_rechts_lied_rotate = < 30, -15 , 0 >; 
      #declare xyz_tux_eye_links_lied_rotate  = < 30, -15 , 0 >; 
      #declare xyz_tux_head_rotate = <-10,5,0>;
      #declare xyz_tux_foot_rechts_rotate = <65,0,0>;
      #declare xyz_tux_foot_rechts_trans = <0,20,-70>;
      #declare xyz_tux_foot_links_rotate = <65,0,0>;
      #declare xyz_tux_foot_links_trans = <0,20,-70>;
      #declare xyz_tux_body_trans  = <0,0,-10>;
      #declare xyz_tux_rotate = <0,-90,0>;
      #declare xyz_tux_trans = <+20,-100,0>;
      #ifdef (xyz_camera_20_27)
       #declare xyz_tux_head_rotate = <-10,-5,0>;
      #end

      init_tux(30)
      object { tux scale .02 translate <0,2.9,0> rotate rot0 rotate rot1 translate tran }

      #declare xyz_tux_eye_rechts_rotate = <+5,-8,10>;
      #declare xyz_tux_eye_links_rotate  = <+5,-8,10>;
      #declare xyz_tux_eye_rechts_lied_rotate = < 40, +15 , 0 >; 
      #declare xyz_tux_eye_links_lied_rotate  = < 40, +15 , 0 >; 
      #declare xyz_tux_head_rotate = <+10,20,0>;
      #declare xyz_tux_foot_rechts_rotate = <65,0,0>;
      #declare xyz_tux_foot_rechts_trans = <0,20,-70>;
      #declare xyz_tux_foot_links_rotate = <65,0,0>;
      #declare xyz_tux_foot_links_trans = <0,20,-70>;
      #declare xyz_tux_body_trans  = <0,0,-15>;
      #declare xyz_tux_rotate = <0,-90,0>;
      #declare xyz_tux_trans = <-120,-90,0>;
      #ifdef (xyz_camera_20_27)
       #declare xyz_tux_head_rotate = <+10,-20,0>;
      #end

      init_tux(30)
      object { tux scale .02 translate <0,2.9,0> rotate rot0 rotate rot1 translate tran }
    #end
  #end
#end

// ############################################################################################################
#ifdef (show_bahn) 
  #declare ro = 0.25;
  #declare zd = 1.25;
  #declare ru = 0.50;
  #declare yd =-1.50;
  #declare rs = 0.20;
  #declare rd = sqrt(yd*yd+zd*zd);
  #declare rdro = rd+2.2*ro;
  #declare ydro = yd-yd*sqrt(rdro/rd);
  #declare zdro = zd*sqrt(rdro/rd);
  #declare segment_0 =
    union
    {
      cylinder { <0,0,+zd>, <0,yd,0>, rs }
      cylinder { <0,0,-zd>, <0,yd,0>, rs }
      texture  { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #declare segment_1 =
    union
    {
      sphere { <0,0,-zd>, ro }
      sphere { <0,0,+zd>, ro }
      sphere { <0,yd,0>, ru }
      scale <10,1,1>
      texture { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #ifdef (show_bob)
    #macro bob_beam (rot00,rot01,tran0,rot10,rot11,tran1)
      #declare bob_rolls =
        union
        {
          difference { sphere { <0,+ydro,-zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,-zd>, <+5*ro,0,-zd>, 1.20*ro } }
          difference { sphere { <0,+ydro,+zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,+zd>, <+5*ro,0,+zd>, 1.20*ro } }
          sphere { <0,+ydro+ro,0>, 2*ro scale <1.0,1,1> }
          cylinder { <0,+ydro+ro,+zdro>, <0,+ydro+ro,-zdro>, 0.8*ro } 
          cylinder { <0,+ydro+ro,-zdro>, <+1.0*ro,+ydro+4.5*ro,-zdro+0.5*ro>, 0.4*ro } 
          cylinder { <0,+ydro+ro,+zdro>, <+1.0*ro,+ydro+4.5*ro,+zdro-0.5*ro>, 0.4*ro } 
          texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
        }
      object { bob_rolls rotate rot10 rotate rot11 translate tran1 }
      object { bob_rolls scale <-1,1,1> rotate rot00 rotate rot01 translate tran0 }
      cylinder 
      {
        tran0+vrotate(vrotate(<0,+ydro+ro,0>,rot00),rot01),
        tran1+vrotate(vrotate(<0,+ydro+ro,0>,rot10),rot11), ro
        texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
      }
    #end
  #end
  
  #macro segment(diff_rot00,diff_rot01)
    #declare akt_seg = akt_seg + 1;
    #declare balls_per_seg = 8;
    #declare diffs_per_ball = 5;
    #ifdef (xyz_camera_ahead)
      #if (s1 > (bob_front_s+6*diff_s0))
        #declare balls_per_seg = 4;
        #declare diffs_per_ball = 10;
      #end
      #if (t1 < t_clock)
        #declare balls_per_seg = 4;
        #declare diffs_per_ball = 10;
      #end
    #end
    #declare all_i = balls_per_seg * diffs_per_ball;
    #local diff_s = diff_s0 / all_i;
    #declare diff_rot0 = diff_rot00 / all_i;
    #declare diff_rot1 = diff_rot01 / all_i;
    #ifndef(invisible)
      object { segment_0 rotate now_rot0 rotate now_rot1 translate now_tran }
    #end
    #declare now_i = 0;
    #while (now_i < all_i)
      #declare now_i = now_i + 1;
      #declare s1 = s1 + diff_s;
//      #if (t1<=t_clock)
        #declare a1 = - vrotate(vrotate(<1,0,0>,now_rot0),now_rot1).y * a00;
        #declare v0 = v1;
        #declare v1 = sqrt(max(v00*v00,v0*v0+2.0*diff_s*a1)); // Mindestgeschwindigkeit
        #declare t0 = t1;
        #declare t1 = t0+2.0*diff_s/max(v0+v1,1E-10);
//      #end
// ############################################################################################################
      #if (paint_3)
        #if (paint_1 & (t1>=t_clock))
          #declare paint_1 = 0;
//#debug concat("### akt_seg ",str(akt_seg,4,0)," :",str(now_i,3,0)," tran <",str(now_tran.x,8,3),",",str(now_tran.y,8,3),",",str(now_tran.z,8,3),">\n")
//#debug concat("0## akt_seg ",str(akt_seg,4,0)," :",str(now_i,3,0)," 0 <",str(now_rot0.x,8,3),",",str(now_rot0.y,8,3),",",str(now_rot0.z,8,3),">\n")
//#debug concat("0## akt_seg ",str(akt_seg,4,0)," :",str(now_i,3,0)," 1 <",str(now_rot1.x,8,3),",",str(now_rot1.y,8,3),",",str(now_rot1.z,8,3),">\n")
#debug concat("### akt_seg ",str(akt_seg,4,0)," :",str(now_i,3,0),", s1 ",str(s1,8,0),", v1 ",str(v1,8,3),", a1 ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")
          #declare bob_back_tran = now_tran;    
          #declare bob_back_rot0 = now_rot0;    
          #declare bob_back_rot1 = now_rot1;    
          #declare bob_pos_s = s1 + 2.5;
          #declare bob_front_s = s1 + 5.5;
        #end
        #if (paint_2 & (bob_pos_s <= s1))
          #declare paint_2 = 0;
          #declare now_rot0_real = now_rot0+diff_rot0*(bob_pos_s-s1)/diff_s;
          #declare now_rot1_real = now_rot1+diff_rot1*(bob_pos_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(vrotate(<bob_pos_s-s1,0,0>,now_rot0),now_rot1);
          #ifdef (show_bob)
            bob_tuxies(now_rot0_real,now_rot1_real,now_tran_real)
          #end
          #ifdef (xyz_camera_ahead)
            #declare xyz_camera         = now_tran_real+vrotate(vrotate(<2.2,4.5,0>,now_rot0_real+<0,0,0>),now_rot1_real+<0,0,0>);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(<10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real);
          #end
          #ifdef (xyz_camera_00_05)
            #declare xyz_camera         = now_tran_real+vrotate(vrotate((1-xyz_camera_00_05)*<4.2,4.5,-10>+xyz_camera_00_05*<2.2,4.5,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(<xyz_camera_00_05*10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real);
          #end
          #ifdef (xyz_camera_07_16)
            #declare xyz_camera         = now_tran_real+vrotate(vrotate(xyz_camera_07_16*<2.2,10,-20>+(1-xyz_camera_07_16)*<2.2,4.5,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(<(1-1.2*xyz_camera_07_16)*10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vnormalize(<0,100,0>*xyz_camera_07_16+vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real));
          #end
          #ifdef (xyz_camera_20_27)
            #declare xyz_camera         = now_tran_real+vrotate(vrotate(xyz_camera_20_27*<2.2,10,30>+(1-xyz_camera_20_27)*<2.2,4.5,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(<(1-1.2*xyz_camera_20_27)*10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vnormalize(<0,100,0>*xyz_camera_20_27+vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real));
          #end
          #ifdef (xyz_camera_33_40)
            #declare xyz_camera         = now_tran_real+vrotate(vrotate(xyz_camera_33_40*<2.2,4.5,-15>+(1-xyz_camera_33_40)*<2.2,4.5,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(<(1-xyz_camera_33_40)*10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vnormalize(<0,10,0>*xyz_camera_33_40+vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real));
          #end
          #ifdef (xyz_camera_55_59)
            #declare xyz_camera         = now_tran_real+xyz_camera_55_59*<-15,15,-15>+vrotate(vrotate((1-xyz_camera_55_59)*<2.2,4.5,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_look_at = now_tran_real+vrotate(vrotate(xyz_camera_55_59*<3,0,0>+<(1-xyz_camera_55_59)*10,3,0>,now_rot0_real),now_rot1_real);
            #declare xyz_camera_sky     = vnormalize(<0,100,0>*xyz_camera_55_59+vrotate(vrotate(<0,1,0>,now_rot0_real),now_rot1_real));
          #end
        #end
        #if (paint_3 & (bob_front_s <= s1))
          #declare paint_3 = 0;
          #declare now_rot0_real = now_rot0+diff_rot0*(bob_front_s-s1)/diff_s;
          #declare now_rot1_real = now_rot1+diff_rot1*(bob_front_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(vrotate(<bob_front_s-s1,0,0>,now_rot0),now_rot1);
          #ifdef (show_bob)
            bob_beam(now_rot0_real,now_rot1_real,now_tran_real,bob_back_rot0,bob_back_rot1,bob_back_tran)
          #end
        #end
      #end
      #ifndef(invisible)
        #if (mod(now_i,diffs_per_ball) = 0)
          object { segment_1 rotate now_rot0 rotate now_rot1 translate now_tran }
        #end
      #end
      #declare now_tran = now_tran + vrotate(vrotate(<diff_s,0,0>,now_rot0),now_rot1);
      #declare now_rot0 = now_rot0 + diff_rot0;
      #declare now_rot1 = now_rot1 + diff_rot1;
    #end
//    #if (v1 <= v00)
//      #debug concat("### akt_seg ",str(akt_seg,8,0)," !vmin!\n")
//    #end
  #end

// ############################################################################################################
// Startberg
// Abfahrt 
  #declare akt_seg = 0;
  #declare bob_front_s = 99999.99;
  #declare bob_pos_s = 99999.99;
  #declare now_tran = <0,0,0>;
  #declare now_rot0 = <0,0,0>;
  #declare now_rot1 = <0,-90,0>;
  #declare diff_s0 = seg_len;

  #ifdef (xyz_camera_ahead)
    #if (t_clock>57.05)
      #declare invisible = 1;
    #end
  #end

  segment(<0,0,0>,<0,0,0>)
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-15>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,1>,<0,0,0>) 
  segment(<0,0,3>,<0,0,0>) 
  segment(<0,0,6>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
// 90 Linkskurve 
  segment(<5,0,0>,<0,0,0>) 
  segment(<10,0,0>,<0,-10,0>) 
  segment(<10,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-10,0,0>,<0,-10,0>) 
  segment(<-10,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,0,0>) 
// 180 Rechtskurve 
  segment(<-5,0,0>,<0,9,0>) 
  segment(<-10,0,0>,<0,9,0>) 
  segment(<-10,0,0>,<0,9,0>) 
  segment(<-5,0,0>,<0,9,0>) 
  segment(<0,0,0>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<5,0,-1>,<0,9,0>) 
  segment(<10,0,-1>,<0,9,0>) 
  segment(<10,0,-1>,<0,9,0>) 
  segment(<5,0,-1>,<0,9,0>) 
// 360 Looping 
  segment(<0,0,7.5>,<0,0,0>) 
  segment(<0,0,7.5>,<0,0,0>) 

  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
// Anstieg
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 180 Linksspirale
  segment(<2.5,0,0>,<0,-4.5,0>) 
  segment(<2.5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-2.5,0,0>,<0,-9,0>) 
  segment(<-2.5,0,0>,<0,-4.5,0>) 
// Gerade nach oben
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 90 Linksspirale
  segment(<2.5,0,0>,<0,-5,0>) 
  segment(<2.5,0,0>,<0,-7.5,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,-2.5>,<0,-11,0>) 
  segment(<5,0,-2.5>,<0,-11.5,0>) 
  segment(<-5,0,-2.5>,<0,-11.5,0>) 
  segment(<-5,0,-2.5>,<0,-11,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-7.5,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// kurzes Auf und Ab bis hinter Kamera
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
// 180 Linksspirale nach unten hinter Kamera
  segment(<2.5,0,-2>,<0,-5,0>) 
  segment(<2.5,0,-2>,<0,-10,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-2.5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// weiter leicht nach unten geradeaus
  segment(<0,0,0>,<0,0,0>) 
//  segment(<0,0,0>,<0,0,0>) 
//  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 360+10 Linksspirale nach unten hinter Kamera
  segment(<2.5,0,0>,<0,-5,0>) 
  segment(<2.5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// geradeaus nach unten
  segment(<0,0,2>,<0,0,0>) 
  segment(<0,0,2>,<0,0,0>) 
// hier horizontal in Richtung +z <0,0,1>
  segment(<0,0,1>,<0,0,0>) 
  segment(<0,0,1>,<0,0,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<-2.5,0,0>,<0,10,0>) 
  segment(<-2.5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,-1>,<0,12,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<2.5,0,-1>,<0,15,0>) 
  segment(<2.5,0,-1>,<0,0,0>) 
// oben geradeaus
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// Linkskurve
  segment(<2.5,-5,0>,<0,-3,0>) 
  segment(<5,-7.5,0>,<0,0,0>) 
  segment(<5,-7.5,0>,<0,0,0>) 
  segment(<0,-7.5,0>,<0,0,0>) 
  segment(<0,-7.5,0>,<0,0,0>) 
  segment(<0,-7.5,0>,<0,0,0>) 
  segment(<0,-7.5,0>,<0,0,0>) 
  segment(<0,-7.5,0>,<0,0,0>) 
  segment(<-5,-7.5,0>,<0,0,0>) 
  segment(<-5,-7.5,0>,<0,0,0>) 
  segment(<-2.5,-7.5,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,-90,0>,<0,90,0>) 
  segment(<0,170,0>,<0,-170,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,-5>, <0,0,0>) 
  segment(<0,0,-5>, <0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 

//#debug concat("### last s1 ",str(s1,8,0),", v1 ",str(v1,8,3),", a1 ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")

  #declare invisible = 1;

#if (t_clock>55)
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-6>, <0,0,0>) 
  segment(<0,0,-4>, <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
  segment(<0,0,0>,  <0,0,0>) 
// #debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," tran <",str(now_tran.x,8,3),",",str(now_tran.y,8,3),",",str(now_tran.z,8,3),">\n")
// #debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," rot0 <",str(now_rot0.x,8,3),",",str(now_rot0.y,8,3),",",str(now_rot0.z,8,3),">\n")
// #debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," rot1 <",str(now_rot1.x,8,3),",",str(now_rot1.y,8,3),",",str(now_rot1.z,8,3),">\n")
#end
#debug concat("### last s1 ",str(s1,8,0),", v1 ",str(v1,8,3),", a1 ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")

  #undef invisible

  #ifdef (xyz_camera_ahead)
    #if (t_clock>57.3)
      #declare invisible = 1;
    #end
  #end

  #declare now_tran = <-32.894,0,-21.945>;
  #declare now_rot0 = <7.5,-90,0>;
  #declare now_rot1 = <0,125,0>;
  #declare diff_s0 = seg_len;
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-14,0>) 
  segment(<0,0,0>,<0,-12,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 

  #declare invisible = 1;
#end

// ############################################################################################################
#ifdef (show_stars)
  #declare camera_direction = vnormalize(xyz_camera_look_at-xyz_camera);
  #declare rrr0 = seed(star_start);
  #declare i = 0;
  #while (i < 750)
    #declare xw = 360*rand(rrr0);
    #declare yw = 360*rand(rrr0);
    #declare se1 = rand(rrr0);
    #declare se2 = rand(rrr0);
    #declare se3 = rand(rrr0);
    #declare se4 = rand(rrr0);
    #declare sc1 = rand(rrr0);
    #declare sc2 = rand(rrr0);
    #declare sw1 = rand(rrr0);
    #declare sw2 = rand(rrr0);
    #declare star_direction = vaxis_rotate(vaxis_rotate(<0,0,1>,<1,0,0>,xw),<0,1,0>,yw);
    #if (1.88<vlength(camera_direction+star_direction))
      union
      {
        superellipsoid { <12+3*se1, 12+3*se2> }
        superellipsoid { <12+3*se3, 12+3*se4> rotate <45,45,0> }
        no_shadow
        scale star_distance * <.08+.02*sc1,.08+.02*sc2,1>
        rotate <-15+30*sw1,-15+30*sw2,0>
        texture { pigment { color rgb .33 } }
        finish { metallic ambient 25 }
        
        translate <0,0,2*star_distance>
        rotate <xw,yw,0>
        translate xyz_camera
      }
    #end
    #declare i = i + 1;
  #end
#end

// ############################################################################################################
#declare sonne2 =
light_source 
{
  <0,0,0>, colour rgb _licht*.33*<1,.5,.1>
}
union 
{
  object { sonne2 translate <-500,+1000,-1000> }
  object { sonne2 translate <+500,+1000,-1000> }
  object { sonne2 translate <-500,-1000,-1000> }
  object { sonne2 translate <+500,-1000,-1000> }
  object { sonne2 translate <-500,+1000,+1000> }
  object { sonne2 translate <+500,+1000,+1000> }
  object { sonne2 translate <-500,-1000,+1000> }
  object { sonne2 translate <+500,-1000,+1000> }
}

#declare sonne =
light_source 
{
  <0,0,0>, colour rgb _licht*<1,.5,.1>/66
}
object { sonne }

// ############################################################################################################
#declare SkyBlue = color red 0.196078 green 0.6 blue 0.8;
#declare MidnightBlue = color red 0.184314 green 0.184314 blue 0.309804;
sky_sphere 
{
  pigment 
  {
    gradient y
    color_map 
    {
      [ 0.1  color _licht*0.01*SkyBlue ]
      [ 0.4  color _licht*0.01*SkyBlue ]
      [ 0.9  color _licht*0.01*MidnightBlue ]
      [ 1.0  color _licht*0.01*MidnightBlue ]
    }
    scale 2
    translate -1
  }
}

// ############################################################################################################
camera 
{
  location xyz_camera
  sky xyz_camera_sky
  look_at xyz_camera_look_at
  direction xyz_camera_zoom*vnormalize(xyz_camera_look_at-xyz_camera)
}
