// ###########################################################################
// #
// # /cluster/src/pov/clustp.pov
// # 11.01.2005 Fred Koegler
// # Zum 29.01.2005 fuer die BraLUG - "Brandenburg Clusternight"
// #
// # Posterhintergrund mit groer Pixelzahl und hoher Antialiasing - Qualitaet
// # (clustp_mask.pov erzeugt aus dem PVMPOV-Logfile eine transparente Bildmaske,
// #  die Bildausschnitte der einzelnen beteiligten Rechner kennzeichnet)
// #
// # HOWTO:
// # - /cluster/src/pov/00a_clustp_pov.sh
// # - /cluster/src/pov/00b_clustp_mask_pov.sh
// # 
// # speziell verwendete POVRay Elemente:
// # - rand & superellipsoid        : Sternenhimmel
// # - cubic_spline & prism & lathe : Tux-Schnabel, Tux-Fuesze
// # - bicubic_patch                : Tux-Fluegel, Tux-Rucksack, Bob-Koerper
// # - blob                         : schwarzer Tux-Koerper
// # - macro & Vektorfunktionen     : Achterbahnform, Bewegung
// # 
// ###########################################################################
#version 3.1;

#declare star_start = 246;
#declare show_stars = 1;

#declare show_bahn = 1;
#declare show_bob  = 1;
#declare show_tux  = 1;

// ############################################################################################################
#declare dist = 200;
#declare star_distance = 3.5*4*dist;
#declare xyz_camera         = <0,0,-dist>;
#declare xyz_camera_look_at = <0,0,0>;
#declare xyz_camera_sky     = <0,1,0>;
#declare xyz_camera_zoom = 1;

#declare t_clock = 145;
//#declare bob_steps = 6;
#declare bob_steps = 5;

#declare balls_per_seg = 10;
#declare diffs_per_ball = 5;
#declare seg_len = 5;
#declare paint_1 = 1;
#declare paint_2 = 1;
#declare paint_3 = 1;
#declare s1 = 0.0;
// ############################################################################################################

global_settings
{
  adc_bailout 0.0039
  ambient_light color rgb .5*<.1,.1,.1>
  assumed_gamma 1.0
  irid_wavelength <0.25, 0.18, 0.14>
  max_trace_level 10
}
#ifdef (show_bob)
  #include "/cluster/src/pov/bob.pov"
  init_bob(bob_steps) 
#end
#ifdef (show_tux)
  #include "/cluster/src/pov/tux.pov" 
  
  #declare xyz_tux_foot_rechts_rotate = <65,0,0>;
  #declare xyz_tux_foot_rechts_trans = <0,20,-70>;
  #declare xyz_tux_foot_links_rotate = <65,0,0>;
  #declare xyz_tux_foot_links_trans = <0,20,-70>;
  #declare xyz_tux_body_trans  = <0,0,-10>;
#end

// ############################################################################################################
#macro bob_tuxies(rot0,rot1,tran)
  #ifdef (show_bob)
    object { bob translate <0,3.0,0> rotate rot0 rotate rot1 translate tran }
  #end
  #ifdef (show_tux)
    #declare vorz = ((vrotate(vrotate(vrotate(<1,0,0>,<0,-20,0>),rot0),rot1)).z < (vrotate(vrotate(vrotate(<1,0,0>,<0,+20,0>),rot0),rot1)).z ? 1 : -1);
    
    #declare xyz_tux_eye_rechts_rotate = <-2,+3,10>;
    #declare xyz_tux_eye_links_rotate  = <-2,+3,10>;
    #declare xyz_tux_eye_rechts_lied_rotate = < 30, -15 , 0 >; 
    #declare xyz_tux_eye_links_lied_rotate  = < 30, -15 , 0 >; 
    #declare xyz_tux_head_rotate = <-10,-15*vorz,0>;
    #declare xyz_tux_rotate = <0,-90,0>;
    #declare xyz_tux_trans = <+20,-100,0>;

    init_tux(30)
    object { tux scale .02 translate <0,2.9,0> rotate rot0 rotate rot1 translate tran }

    #declare xyz_tux_eye_rechts_rotate = <+5,-8,10>;
    #declare xyz_tux_eye_links_rotate  = <+5,-8,10>;
    #declare xyz_tux_eye_rechts_lied_rotate = < 40, +15 , 0 >; 
    #declare xyz_tux_eye_links_lied_rotate  = < 40, +15 , 0 >; 
    #declare xyz_tux_head_rotate = <+10,-20*vorz,0>;
    #declare xyz_tux_trans = <-120,-90,0>;

    init_tux(30)
    object { tux scale .02 translate <0,2.9,0> rotate rot0 rotate rot1 translate tran }
  #end
#end

// ############################################################################################################
#ifdef (show_bahn) 
  #declare ro = 0.25;
  #declare zd = 1.25;
  #declare ru = 0.50;
  #declare yd =-1.50;
  #declare rs = 0.20;
  #declare rd = sqrt(yd*yd+zd*zd);
  #declare rdro = rd+2.2*ro;
  #declare ydro = yd-yd*sqrt(rdro/rd);
  #declare zdro = zd*sqrt(rdro/rd);
  #declare segment_0 =
    union
    {
      cylinder { <0,0,+zd>, <0,yd,0>, rs }
      cylinder { <0,0,-zd>, <0,yd,0>, rs }
      texture  { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #declare segment_1 =
    union
    {
      sphere { <0,0,-zd>, ro }
      sphere { <0,0,+zd>, ro }
      sphere { <0,yd,0>, ru }
//      scale <10,1,1>
      scale <8,1,1>
      texture { pigment { color rgb <.8,.05,.04> } finish  { phong 0.1 phong_size 10 } }
    }
  #ifdef (show_bob)
    #macro bob_beam (rot00,rot01,tran0,rot10,rot11,tran1)
      #declare bob_rolls =
        union
        {
          difference { sphere { <0,+ydro,-zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,-zd>, <+5*ro,0,-zd>, 1.20*ro } }
          difference { sphere { <0,+ydro,+zdro>, 2.0*ro scale <2.0,1,1> } cylinder { <-5*ro,0,+zd>, <+5*ro,0,+zd>, 1.20*ro } }
          sphere { <0,+ydro+ro,0>, 2*ro scale <1.0,1,1> }
          cylinder { <0,+ydro+ro,+zdro>, <0,+ydro+ro,-zdro>, 0.8*ro } 
          cylinder { <0,+ydro+ro,-zdro>, <+1.0*ro,+ydro+4.5*ro,-zdro+0.5*ro>, 0.4*ro } 
          cylinder { <0,+ydro+ro,+zdro>, <+1.0*ro,+ydro+4.5*ro,+zdro-0.5*ro>, 0.4*ro } 
          texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
        }
      object { bob_rolls rotate rot10 rotate rot11 translate tran1 }
      object { bob_rolls scale <-1,1,1> rotate rot00 rotate rot01 translate tran0 }
      cylinder 
      {
        tran0+vrotate(vrotate(<0,+ydro+ro,0>,rot00),rot01),
        tran1+vrotate(vrotate(<0,+ydro+ro,0>,rot10),rot11), ro
        texture { pigment { color rgb <.8,.8,.05> } finish  { reflection 0.01 phong 0.1 phong_size 10 } }
      }
    #end
  #end
  
  #macro segment(diff_rot00,diff_rot01)
    #declare akt_seg = akt_seg + 1;
    #declare balls_per_seg = 8;
    #declare diffs_per_ball = 5;
    #declare all_i = balls_per_seg * diffs_per_ball;
    #local diff_s = diff_s0 / all_i;
    #declare diff_rot0 = diff_rot00 / all_i;
    #declare diff_rot1 = diff_rot01 / all_i;
    #ifndef(invisible)
      object { segment_0 rotate now_rot0 rotate now_rot1 translate now_tran }
    #end
  
    #declare now_i = 0;
    #while (now_i < all_i)
      #declare now_i = now_i + 1;
      #declare s1 = s1 + diff_s;
// ############################################################################################################
      #if (paint_3)
        #if (paint_1 & (s1>=t_clock))
          #declare paint_1 = 0;
//#debug concat("0## akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," 0 <",str(now_rot0.x,8,3),",",str(now_rot0.y,8,3),",",str(now_rot0.z,8,3),">\n")
//#debug concat("0## akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0)," 1 <",str(now_rot1.x,8,3),",",str(now_rot1.y,8,3),",",str(now_rot1.z,8,3),">\n")
//#debug concat("### akt_seg ",str(akt_seg,8,0)," :",str(now_i,8,0),", s1 ",str(s1,8,0),", v1 ",str(v1,8,3),", a1 ",str(a1,8,3),", t1 ",str(t1,8,3),", t_clock ",str(t_clock,8,3),">\n")
          #declare bob_back_tran = now_tran;    
          #declare bob_back_rot0 = now_rot0;    
          #declare bob_back_rot1 = now_rot1;    
          #declare bob_pos_s = s1 + 2.5;
          #declare bob_front_s = s1 + 5.5;
        #end
        #if (paint_2 & (bob_pos_s <= s1))
          #declare paint_2 = 0;
          #declare now_rot0_real = now_rot0+diff_rot0*(bob_pos_s-s1)/diff_s;
          #declare now_rot1_real = now_rot1+diff_rot1*(bob_pos_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(vrotate(<bob_pos_s-s1,0,0>,now_rot0),now_rot1);
          #ifdef (show_bob)
            bob_tuxies(now_rot0_real,now_rot1_real,now_tran_real)
          #end
        #end
        #if (paint_3 & (bob_front_s <= s1))
          #declare paint_3 = 0;
          #declare now_rot0_real = now_rot0+diff_rot0*(bob_front_s-s1)/diff_s;
          #declare now_rot1_real = now_rot1+diff_rot1*(bob_front_s-s1)/diff_s;
          #declare now_tran_real = now_tran + vrotate(vrotate(<bob_front_s-s1,0,0>,now_rot0),now_rot1);
          #ifdef (show_bob)
            bob_beam(now_rot0_real,now_rot1_real,now_tran_real,bob_back_rot0,bob_back_rot1,bob_back_tran)
          #end
#declare t_clock = t_clock + 89.5;
#declare paint_1 = 1;
#declare paint_2 = 1;
#declare paint_3 = 1;
#declare bob_front_s = 99999.99;
#declare bob_pos_s = 99999.99;
        #end
      #end
      #ifndef(invisible)
        #if (mod(now_i,diffs_per_ball) = 0)
          object { segment_1 rotate now_rot0 rotate now_rot1 translate now_tran }
        #end
      #end
      #declare now_tran = now_tran + vrotate(vrotate(<diff_s,0,0>,now_rot0),now_rot1);
      #declare now_rot0 = now_rot0 + diff_rot0;
      #declare now_rot1 = now_rot1 + diff_rot1;
    #end
//    #if (v1 <= v00)
//      #debug concat("### akt_seg ",str(akt_seg,8,0)," !vmin!\n")
//    #end
  #end
    
// ############################################################################################################
// Startberg
// Abfahrt 
  #declare akt_seg = 0;
  #declare now_tran = <0,+23,-253>;
  #declare now_rot0 = <0,0,0>;
  #declare now_rot1 = <0,-90,0>;
  #declare bob_front_s = 99999.99;
  #declare bob_pos_s = 99999.99;
//  #declare all_i = balls_per_seg * diffs_per_ball;
  #declare diff_s0 = seg_len;

// Abfahrt 
  segment(<0,0,0>,<0,0,0>)
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-15>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,15>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
// Abfahrt 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-10>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
// 90 Linkskurve 
  segment(<5,0,0>,<0,0,0>) 
  segment(<10,0,0>,<0,-10,0>) 
  segment(<10,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-10,0,0>,<0,-10,0>) 
  segment(<-10,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,0,0>) 
// 180 Rechtskurve 
  segment(<-5,0,0>,<0,9,0>) 
  segment(<-10,0,0>,<0,9,0>) 
  segment(<-10,0,0>,<0,9,0>) 
  segment(<-5,0,0>,<0,9,0>) 
  segment(<0,0,0>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<0,0,-1>,<0,9,0>) 
  segment(<5,0,-1>,<0,9,0>) 
  segment(<10,0,-1>,<0,9,0>) 
  segment(<10,0,-1>,<0,9,0>) 
  segment(<5,0,-1>,<0,9,0>) 
// 360 Looping 
  segment(<0,0,7.5>,<0,0,0>) 
  segment(<0,0,7.5>,<0,0,0>) 

  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,+1,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,0,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
  segment(<0,-1,10>,<0,0,0>) 
// Anstieg
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 180 Linksspirale
  segment(<2.5,0,0>,<0,-4.5,0>) 
  segment(<2.5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<5,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<0,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-5,0,0>,<0,-9,0>) 
  segment(<-2.5,0,0>,<0,-9,0>) 
  segment(<-2.5,0,0>,<0,-4.5,0>) 
// Gerade nach oben
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 90 Linksspirale
  segment(<2.5,0,0>,<0,-5,0>) 
  segment(<2.5,0,0>,<0,-7.5,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,-2.5>,<0,-11,0>) 
  segment(<5,0,-2.5>,<0,-11.5,0>) 
  segment(<-5,0,-2.5>,<0,-11.5,0>) 
  segment(<-5,0,-2.5>,<0,-11,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-7.5,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// kurzes Auf und Ab bis hinter Kamera
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-5>,<0,0,0>) 
  segment(<0,0,-2.5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,5>,<0,0,0>) 
  segment(<0,0,2.5>,<0,0,0>) 
// 180 Linksspirale nach unten hinter Kamera
  segment(<2.5,0,-2>,<0,-5,0>) 
  segment(<2.5,0,-2>,<0,-10,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<5,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<0,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-5,0,0>,<0,-15,0>) 
  segment(<-2.5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// weiter leicht nach unten geradeaus
  segment(<0,0,0>,<0,0,0>) 
//  segment(<0,0,0>,<0,0,0>) 
//  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// 360+10 Linksspirale nach unten hinter Kamera
  segment(<2.5,0,0>,<0,-5,0>) 
  segment(<2.5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-10,0>) 
  segment(<-2.5,0,0>,<0,-5,0>) 
// geradeaus nach unten
  segment(<0,0,2>,<0,0,0>) 
  segment(<0,0,2>,<0,0,0>) 
// hier horizontal in Richtung +z <0,0,1>
  segment(<0,0,1>,<0,0,0>) 
  segment(<0,0,1>,<0,0,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,1>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>)
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
  segment(<0,0,0>,<0,1,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<-2.5,0,0>,<0,10,0>) 
  segment(<-2.5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<-5,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
  segment(<0,0,0>,<0,10,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,0>,<0,12,0>)
  segment(<0,0,0>,<0,12,0>) 
  segment(<0,0,-1>,<0,12,0>) 
// 360 Rechtsspirale nach oben enger werdend
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<0,0,0>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<5,0,-1>,<0,15,0>) 
  segment(<2.5,0,-1>,<0,15,0>) 
  segment(<2.5,0,-1>,<0,0,0>) 
// oben geradeaus
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
  segment(<0,0,0>,<0,0,0>) 
// Linkskurve
  segment(<2.5,0,0>,<0,-5,0>) 
  segment(<2.5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<5,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
  segment(<0,0,0>,<0,-10,0>) 
#end

// ############################################################################################################
// Sternenhimmel steht still im Raum, werden optimiert nur erzeugt, wenn sie im Sichtfeld der Kamera sind
#ifdef (show_stars)
  #declare camera_direction = vnormalize(xyz_camera_look_at-xyz_camera);
  #declare star_start = 246;
  #declare rrr0 = seed(star_start);
  #declare i = 0;
  #while (i < 750)
    #declare xw = 360*rand(rrr0);
    #declare yw = 360*rand(rrr0);
    #declare se1 = rand(rrr0);
    #declare se2 = rand(rrr0);
    #declare se3 = rand(rrr0);
    #declare se4 = rand(rrr0);
    #declare sc1 = rand(rrr0);
    #declare sc2 = rand(rrr0);
    #declare sw1 = rand(rrr0);
    #declare sw2 = rand(rrr0);
    #declare star_direction = vaxis_rotate(vaxis_rotate(<0,0,1>,<1,0,0>,xw),<0,1,0>,yw);
    #if (1.88<vlength(camera_direction+star_direction))
      union
      {
        superellipsoid { <12+3*se1, 12+3*se2> }
        superellipsoid { <12+3*se3, 12+3*se4> rotate <45,45,0> }
        no_shadow
        scale star_distance * <.08+.02*sc1,.08+.02*sc2,1>
        rotate <-15+30*sw1,-15+30*sw2,0>
        texture { pigment { color rgb .33 } }
        finish { metallic ambient 25 }
        
        translate <0,0,2*star_distance>
        rotate <xw,yw,0>
        translate xyz_camera
      }
    #end
    #declare i = i + 1;
  #end
#end

// ############################################################################################################
#declare sonne =
light_source { <0,0,0>, colour rgb .33*<1,.5,.1> }
union 
{
  object { sonne translate <-500,+1000,-1000> }
  object { sonne translate <+500,+1000,-1000> }
  object { sonne translate <-500,-1000,-1000> }
  object { sonne translate <+500,-1000,-1000> }
  object { sonne translate <-500,+1000,+1000> }
  object { sonne translate <+500,+1000,+1000> }
  object { sonne translate <-500,-1000,+1000> }
  object { sonne translate <+500,-1000,+1000> }
}

#declare sonne =
light_source { <0,0,0>, colour rgb <1,.5,.1>/66 }
object { sonne }

// ############################################################################################################
#declare SkyBlue = color red 0.196078 green 0.6 blue 0.8;
#declare MidnightBlue = color red 0.184314 green 0.184314 blue 0.309804;
sky_sphere 
{
  pigment 
  {
    gradient y
    color_map 
    {
      [ 0.1  color 0.01*SkyBlue ]
      [ 0.4  color 0.01*SkyBlue ]
      [ 0.9  color 0.01*MidnightBlue ]
      [ 1.0  color 0.01*MidnightBlue ]
    }
    scale 2
    translate -1
  }
}

// ############################################################################################################
camera {
  location xyz_camera
  sky xyz_camera_sky
  direction xyz_camera_zoom*vnormalize(xyz_camera_look_at-xyz_camera)
  look_at xyz_camera_look_at
}
